@@ -13,7 +13,7 @@ def mk_jwt_middleware(secret, verify=True):
         auth_header = req.headers.get('Authorization', '')
         token = auth_header[7:]
         try:
-            decoded = jwt.decode(token, secret, verify=False)
+            decoded = jwt.decode(token, secret, verify=verify)
             req.token = decoded
             return await handler(req)
         except jwt.DecodeError as error:
